import 'package:equatable/equatable.dart';

abstract class LoginState extends Equatable {
  const LoginState();

  @override
  List<Object> get props => [];
}

class LoginInitial extends LoginState {}

class LoginLoading extends LoginState {}

class LoginSuccess extends LoginState {}

class LoginFailure extends LoginState {
  final String error;

  const LoginFailure(this.error);

  @override
  List<Object> get props => [error];
}

class LoginFieldsState extends LoginState {
  final bool areFieldsFilled;

  const LoginFieldsState(this.areFieldsFilled);

  @override
  List<Object> get props => [areFieldsFilled];
}
